@@ -654,7 +654,7 @@ impl crate::copyset::CopySet for SetU32 {
 #[derive(Debug)]
 pub struct IntoIter {
     iter: Iter<'static>,
-    set: SetU32,
+    _set: SetU32,
 }
 impl IntoIterator for SetU32 {
     type Item = u32;
@@ -664,7 +664,7 @@ impl IntoIterator for SetU32 {
         let iter = unsafe { std::mem::transmute(self.private_iter()) };
         IntoIter {
             iter,
-            set: self,
+            _set: self,
         }
     }
 }
@@ -1249,12 +1249,7 @@ impl SetU32 {
     /// Clears the set, returning all elements in an iterator.
     #[inline]
     pub fn drain<'a>(&'a mut self) -> impl Iterator<Item=u32> + 'a {
-        let set: SetU32 = std::mem::replace(self, SetU32::new());
-        let iter = unsafe { std::mem::transmute(set.private_iter()) };
-        IntoIter {
-            iter,
-            set,
-        }
+        std::mem::replace(self, SetU32::new()).into_iter()
     }
 
     fn internal<'a>(&'a self) -> Internal<'a> {
